/**
 * Repraesentation eines Kalah-Spielbrett mit Stellungsbewerter
 * 
 * @author Dietrich Boles (Universitaet Oldenburg)
 * @version 1.0 (29.01.2006)
 * 
 */
public class WertSpielbrett extends Spielbrett {

	/**
	 * hoechst moeglicher Wert der Spielbrettbewertung
	 */
	public final static int MAX_WERT = Spielbrett.ANZAHL_KOERNER;

	/**
	 * schlechtester Wert der Spielbrettbewertung
	 */
	public final static int MIN_WERT = -MAX_WERT;

	/**
	 * Mittelwert der Spielbrettbewertung
	 */
	public final static int MITTEL_WERT = 0;

	/**
	 * Konstruktor; erzeugt eine Kopie des uebergebenen Spielbrettes
	 * 
	 * @param brett
	 *            das zu kopierende Spielbrett
	 */
	public WertSpielbrett(Spielbrett brett) {
		super(brett);
	}

	/**
	 * einfacher Stellungsbewerter; je groesser der gelieferte Wert, desto
	 * besser steht Spieler A; je kleiner der gelieferte Wert, desto besser
	 * steht Spieler B
	 * 
	 * @param spielBeendet
	 *            true bedeutet, dass das Spiel beendet ist
	 * @return berechneter Stellungswert des aktuellen Spielbrettes
	 */
	public int bewerteStellung(boolean spielBeendet) {
		if (!spielBeendet) {
			return this.liefereAnzahlKoernerInKalahA()
					- this.liefereAnzahlKoernerInKalahB();
		}

		// Spiel ist beendet; also muessen auch noch die "Reste"
		// betrachtet werden
		int diff = (this.liefereAnzahlKoernerInKalahA() + this
				.liefereAnzahlKoernerVonSpielerA())
				- (this.liefereAnzahlKoernerInKalahB() + this
						.liefereAnzahlKoernerVonSpielerB());
		if (diff > 0) { // Spieler A hat gewonnen
			return WertSpielbrett.MAX_WERT;
		} else if (diff < 0) { // Spieler B hat gewonnen
			return WertSpielbrett.MIN_WERT;
		} else { // Unentschieden
			return WertSpielbrett.MITTEL_WERT;
		}
	}
}
